package de.espirit.firstspirit.opt.example.webedit.report;

import org.jetbrains.annotations.Nullable;


/**
 * Defines an object for use in reports based on {@link TextBlocksWebeditReportPlugin}.
 */
public class TextBlocksObject {

	private String _title;
	private String _text;
	private String _imageUrl;


	/**
	 * Constructor. Stores {@link String} objects for title, text and a thumbnail image in fields.
	 *
	 * @param title	A short title used to enable users to quickly identify this object as it is displayed in a report.
	 * @param text	 The text of this object. This should be the most significant content and will be used by {@link
	 *                 TextBlocksReportPluginRenderer} to specify transfer data for drag-and-drop operations.
	 * @param imageUrl The path to a thumbnail image, as an absolute or relative URL.
	 */
	TextBlocksObject(final String title, final String text, final String imageUrl) {
		_title = title;
		_text = text;
		_imageUrl = imageUrl;
	}


	/**
	 * Provides the "title" of this object.
	 *
	 * @return The title part of this object. If the {@link TextBlocksObject} does not contain a title, "No Title" is
	 *         returned.
	 */
	public String getTitle() {
		return _title != null ? _title : "No Title";
	}


	/**
	 * Provides the text stored in this object.
	 *
	 * @return The text part of this object.
	 */
	@Nullable
	public String getText() {
		return _text;
	}


	/**
	 * Provides the path to a thumbnail image file.
	 *
	 * @return The absolute or relative URL to the thumbnail image file.
	 */
	@Nullable
	public String getImageUrl() {
		return _imageUrl;
	}

}
