package de.espirit.firstspirit.opt.example.webedit.report;

import de.espirit.firstspirit.access.BaseContext;
import de.espirit.firstspirit.webedit.plugin.report.ReportPluginRenderer;


/**
 * Defines a renderer component that operates on {@link TextBlocksObject}s in order to provide {@link String}s for
 * display in the WebClient report plug-in.
 */
public class TextBlocksReportPluginRenderer implements ReportPluginRenderer<TextBlocksObject> {

	final BaseContext _context;


	/**
	 * Constructor. Stores the context as a field.
	 *
	 * @param context The context the report operates in.
	 */
	TextBlocksReportPluginRenderer(final BaseContext context) {
		_context = context;
	}


	/**
	 * Returns the thumbnail path stored in {@code object}.
	 *
	 * @param object The object that is to be rendered in the report list.
	 * @return The thumbnail file path.
	 */
	@Override
	public String getThumbnail(final TextBlocksObject object) {
		return object.getImageUrl();
	}


	/**
	 * Returns the title text to be shown for {@code object}.
	 *
	 * @param object The object that is to be rendered in the report list.
	 * @return A title text.
	 */
	@Override
	public String getTitle(final TextBlocksObject object) {
		return object.getTitle();
	}


	/**
	 * Returns the descriptive text of {@code object}.
	 *
	 * @param object The object that is to be rendered in the report list.
	 * @return A descriptive text.
	 */
	@Override
	public String getDescription(final TextBlocksObject object) {
		return object.getText();
	}


	/**
	 * Returns transfer data to be used in drag-and-drop operations (e.g. in association with an FS_BUTTON defined in a
	 * template). In this case, the descriptive text of {@code object} is used.
	 *
	 * @param object The object that is to be rendered in the report list.
	 * @return The descriptive text of {@code object}.
	 */
	@Override
	public String getTransferData(final TextBlocksObject object) {
		return object.getText();
	}
}
